@@ -2,7 +2,7 @@
 /*
  *  Authors: Jeffrey Stedfast <fejj@ximian.com>
  *
- *  Copyright 2001 Ximian, Inc. (www.ximian.com)
+ *  Copyright 2001-2004 Ximian, Inc. (www.ximian.com)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,11 +24,6 @@
 #ifndef __GMIME_STREAM_H__
 #define __GMIME_STREAM_H__
 
-#ifdef __cplusplus
-extern "C" {
-#pragma }
-#endif /* __cplusplus */
-
 #include <glib.h>
 #include <glib-object.h>
 #include <sys/types.h>
@@ -37,6 +32,11 @@ extern "C" {
 
 #include <gmime/gmime-type-utils.h>
 
+#ifdef __cplusplus
+extern "C" {
+#pragma }
+#endif /* __cplusplus */
+
 #define GMIME_TYPE_STREAM            (g_mime_stream_get_type ())
 #define GMIME_STREAM(obj)            (GMIME_CHECK_CAST ((obj), GMIME_TYPE_STREAM, GMimeStream))
 #define GMIME_STREAM_CLASS(klass)    (GMIME_CHECK_CLASS_CAST ((klass), GMIME_TYPE_STREAM, GMimeStreamClass))
@@ -72,16 +72,16 @@ struct _GMimeStream {
 struct _GMimeStreamClass {
 	GObjectClass parent_class;
 	
-	ssize_t  (*read)    (GMimeStream *stream, char *buf, size_t len);
-	ssize_t  (*write)   (GMimeStream *stream, char *buf, size_t len);
-	int      (*flush)   (GMimeStream *stream);
-	int      (*close)   (GMimeStream *stream);
-	gboolean (*eos)     (GMimeStream *stream);
-	int      (*reset)   (GMimeStream *stream);
-	off_t    (*seek)    (GMimeStream *stream, off_t offset, GMimeSeekWhence whence);
-	off_t    (*tell)    (GMimeStream *stream);
-	ssize_t  (*length)  (GMimeStream *stream);
-	GMimeStream *(*substream) (GMimeStream *stream, off_t start, off_t end);
+	ssize_t  (* read)   (GMimeStream *stream, char *buf, size_t len);
+	ssize_t  (* write)  (GMimeStream *stream, const char *buf, size_t len);
+	int      (* flush)  (GMimeStream *stream);
+	int      (* close)  (GMimeStream *stream);
+	gboolean (* eos)    (GMimeStream *stream);
+	int      (* reset)  (GMimeStream *stream);
+	off_t    (* seek)   (GMimeStream *stream, off_t offset, GMimeSeekWhence whence);
+	off_t    (* tell)   (GMimeStream *stream);
+	ssize_t  (* length) (GMimeStream *stream);
+	GMimeStream * (* substream) (GMimeStream *stream, off_t start, off_t end);
 };
 
 
@@ -92,7 +92,7 @@ void g_mime_stream_construct (GMimeStream *stream, off_t start, off_t end);
 
 /* public methods */
 ssize_t   g_mime_stream_read    (GMimeStream *stream, char *buf, size_t len);
-ssize_t   g_mime_stream_write   (GMimeStream *stream, char *buf, size_t len);
+ssize_t   g_mime_stream_write   (GMimeStream *stream, const char *buf, size_t len);
 int       g_mime_stream_flush   (GMimeStream *stream);
 int       g_mime_stream_close   (GMimeStream *stream);
 gboolean  g_mime_stream_eos     (GMimeStream *stream);
@@ -103,8 +103,10 @@ ssize_t   g_mime_stream_length  (GMimeStream *stream);
 
 GMimeStream *g_mime_stream_substream (GMimeStream *stream, off_t start, off_t end);
 
+#ifndef GMIME_DISABLE_DEPRECATED
 void      g_mime_stream_ref     (GMimeStream *stream);
 void      g_mime_stream_unref   (GMimeStream *stream);
+#endif
 
 void      g_mime_stream_set_bounds (GMimeStream *stream, off_t start, off_t end);
 
